@@ -8,7 +8,7 @@ Authentication <- R6::R6Class(
     token = NULL,
     method = NULL
   ),
-  lock_objects = F,
+  lock_objects = FALSE,
   parent_env = emptyenv()
 )
 
@@ -124,10 +124,7 @@ gar_auth <- function(token = NULL,
   
   ## output info on token saved
   gar_token_info()
-  
-  if(!gar_check_existing_token()){
-    warning("Token has different options() than currently set.", call. = FALSE)
-  }
+  gar_check_existing_token()
   
   ## return google_token above
   return(invisible(google_token)) 
