@@ -80,8 +80,15 @@ gar_batch <- function(call_list,
   if(req$status_code == 404){
     stop("Batch Request: 404 Not Found", call. = FALSE)
   }
-  
-  batch_content <-  parseBatchResponse(req)
+
+  batch_content <-  tryCatch(parseBatchResponse(req),
+                             error = function(ee){
+                               if(getOption("googleAuthR.verbose") < 3){
+                                 tmp <- tempfile(fileext = ".rds")
+                                 saveRDS(req, file = tmp)
+                                 stop("Error with batch response - writing response to ",tmp)
+                               }
+                             })
   
   if(!is.null(batch_content[[1]]$content[[1]]$error$message)){
     stop(batch_content[[1]]$content[[1]]$error$message, call. = FALSE) 
@@ -190,7 +197,8 @@ gar_batch_walk <- function(f,
                                                       default = "https://www.googleapis.com/batch")){
   
   if(!is.gar_function(f)){
-    stop("Passed function f is not of class gar_function (not generated by gar_api_generator?)", call. = FALSE)
+    stop("Passed function f is not of class gar_function (not generated by gar_api_generator?)", 
+         call. = FALSE)
   }
   
   limit_batch <- split(walk_vector, ceiling(seq_along(walk_vector) / batch_size))
@@ -261,7 +269,6 @@ gar_batch_walk <- function(f,
 #' @noRd
 parseBatchResponse <- function(batch_response){
 
-  
   b_content <- textConnection(httr::content(batch_response, as="text", encoding = "UTF-8"))
   r <- readLines(b_content)
   
@@ -284,7 +291,7 @@ parseBatchResponse <- function(batch_response){
     }
     jsonlite::fromJSON(unlist(split_vector(x, index, remove_splits = FALSE)))
   })
-  
+
   responses_meta <- lapply(responses, function(x){
     index <- c(1:2)
     unlist(split_vector(x, index, remove_splits = FALSE))
@@ -386,8 +393,10 @@ doBatchRequest <- function(batched,
                            batch_endpoint){
   
   if(batch_endpoint == "https://www.googleapis.com/batch"){
-    warning("Deprecated batch endpoint being used.  Use option('googleAuthR.batch_endpoint') 
-            to select specific endpoint for this API.")  
+    stop("Deprecated batch endpoint being used.  Use options('googleAuthR.batch_endpoint') to select 
+          specific endpoint for this API. See 
+         http://code.markedmondson.me/googleAuthR/articles/advanced-building.html#batching-api-requests", 
+         call. = FALSE)  
   }
   
   arg_list <- list(url = batch_endpoint, 
