@@ -109,6 +109,7 @@ gar_api_generator <- function(baseURI,
                    pars_arguments=NULL,
                    the_body=NULL,
                    batch=FALSE,
+                   url_override=NULL,
                    ...){
 
     # extract the shiny token from the right environments
@@ -120,7 +121,7 @@ gar_api_generator <- function(baseURI,
     if(any(with_shiny_env)){
       call_args <- as.list(match.call(definition = sys.function(with_shiny_env),
                                       call = sys.call(with_shiny_env),
-                                      expand.dots = F)[-1])
+                                      expand.dots = FALSE)[-1])
       ## gets the calling function of with_shiny to evaluate the reactive token in
       f <- do.call("parent.frame", args = list(), envir = sys.frame(with_shiny_env))
       ## evaluates the shiny_access_token in the correct environment
@@ -150,8 +151,13 @@ gar_api_generator <- function(baseURI,
     if(!is.null(pars_args)){
       pars <- paste0("?", pars)
     }
-
-    req_url <- paste0(baseURI, path, pars)
+    
+    # change the URL for the API request
+    if(!is.null(url_override)){
+      req_url <- url_override
+    } else {
+      req_url <- paste0(baseURI, path, pars)
+    }
 
     ## if called with gar_batch wrapper set batch to TRUE
     with_gar_batch <- which(grepl("gar_batch", all_envs))
@@ -223,18 +229,22 @@ is.gar_function <- function(x){
 #' @param f A function of a http request
 #'
 #' @keywords internal
+#' @importFrom httr with_verbose content
+#' @importFrom jsonlite fromJSON
+#' @importFrom utils browseURL
 retryRequest <- function(f){
 
   verbose <- getOption("googleAuthR.verbose")
 
   if(verbose <= 1){
-    the_request <- try(httr::with_verbose(f))
+    the_request <- try(with_verbose(f))
   } else {
     the_request <- try(f)
   }
 
   if(is.error(the_request)){
-    stop("Request failed before finding status code: ", error.message(the_request), call. = FALSE)
+    stop("Request failed before finding status code: ", 
+         error.message(the_request), call. = FALSE)
   } else {
     status_code <- as.character(the_request$status_code)
   }
@@ -242,14 +252,29 @@ retryRequest <- function(f){
   if(!(grepl("^20",status_code))){
     myMessage("Request Status Code: ", status_code, level = 3)
 
-    content <- try(jsonlite::fromJSON(httr::content(the_request,
-                                              as = "text",
-                                              type = "application/json",
-                                              encoding = "UTF-8")))
+    content <- try(fromJSON(content(the_request,
+                                    as = "text",
+                                    type = "application/json",
+                                    encoding = "UTF-8")))
     if(is.error(content)){
 
       warning("No JSON content found in request", call. = FALSE)
-      error <- "Could not fetch response"
+      
+      # perhaps it is not JSON and a webpage with error instead
+      if(grepl("invalid char in json text",error.message(content))){
+
+        error_html <- content(the_request,
+                              as = "text",
+                              type = "text/html",
+                              encoding = "UTF-8")
+        browseURL(error_html)
+        
+        error <- "API error: returned web page that has been opened in your default browser if possible"
+        cat(error_html)
+      } else {
+        error <- "Could not fetch response"
+      }
+
 
     } else if(exists("error", where=content)) {
 
@@ -311,16 +336,20 @@ doHttrRequest <- function(url,
                           customConfig=NULL,
                           simplifyVector=getOption("googleAuthR.jsonlite.simplifyVector")){
 
-  arg_list <- list(verb = request_type,
-                   url = url,
-                   config = get_google_token(shiny_access_token),
-                   body = the_body,
-                   encode = if(!is.null(customConfig$encode)) customConfig$encode else "json",
-                   add_headers("Accept-Encoding" = "gzip"),
-                   user_agent(paste0("googleAuthR/",
-                                     packageVersion("googleAuthR"),
-                                     " (gzip)"))
-                   )
+  
+  arg_list <- list(
+    verb = request_type,
+    url = url,
+    config = get_google_token(shiny_access_token),
+    body = the_body,
+    encode = if (!is.null(customConfig$encode)) customConfig$encode else "json",
+    add_headers("Accept-Encoding" = "gzip"),
+    user_agent(paste0("googleAuthR/",
+                     packageVersion("googleAuthR"),
+                     " (gzip)")),
+    times = getOption("googleAuthR.HttrRetryTimes"),
+    terminate_on = getOption("googleAuthR.HttrRetryTerminateOn")
+  )
 
   arg_list <- modify_custom_config(arg_list, customConfig = customConfig)
 
